@@ -12,7 +12,7 @@ use warnings;
 
 package App::Magpie::Action::Checkout;
 {
-  $App::Magpie::Action::Checkout::VERSION = '1.122610';
+  $App::Magpie::Action::Checkout::VERSION = '1.122700';
 }
 # ABSTRACT: checkout command implementation
 
@@ -20,6 +20,8 @@ use File::pushd;
 use Moose;
 use Path::Class;
 
+use App::Magpie::URPM;
+
 with 'App::Magpie::Role::Logging';
 with 'App::Magpie::Role::RunningCommand';
 
@@ -28,6 +30,17 @@ with 'App::Magpie::Role::RunningCommand';
 sub run {
     my ($self, $pkg, $directory) = @_;
 
+    # check if argument is a perl module or a mageia rpm name
+    if ( not _pkg_exist_in_svn($pkg) ) {
+        $self->log( "$pkg doesn't exist, looking if it's a perl module" );
+        my $urpm = App::Magpie::URPM->instance;
+        my ($realpkg) = map { $_->name } $urpm->packages_providing( $pkg );
+        $self->log_fatal( "$pkg doesn't exist and isn't a perl module, aborting" )
+            unless _pkg_exist_in_svn( $realpkg );
+        $self->log( "$pkg is a module provided by $realpkg" );
+        $pkg = $realpkg;
+    }
+
     # check out the package, or update the local checkout
     my $dir    = defined($directory) ? dir( $directory ) : dir();
     my $pkgdir = $dir->subdir( $pkg );
@@ -47,6 +60,19 @@ sub run {
 }
 
 
+# -- private subs
+
+#
+#   my $bool = _pkg_exist_in_svn( $pkg );
+#
+# return true if $pkg is a real package in cauldron.
+#
+sub _pkg_exist_in_svn {
+    my $pkg = shift;
+    my $svn = "svn+ssh://svn.mageia.org/svn/packages/cauldron";
+    return system( "svn ls $svn/$pkg >/dev/null 2>&1" ) == 0;
+}
+
 
 1;
 
@@ -60,7 +86,7 @@ App::Magpie::Action::Checkout - checkout command implementation
 
 =head1 VERSION
 
-version 1.122610
+version 1.122700
 
 =head1 SYNOPSIS
 
